@@ -237,20 +237,21 @@ Chapter X: The del and null Weeds
 """
 from __future__ import absolute_import, division, print_function
 
-from collections import Iterable, Sequence, Mapping
-from copy import deepcopy
+from collections import Mapping, Sequence
 from datetime import datetime
-from enum import Enum
 from functools import reduce
 from json import JSONEncoder, dumps as json_dumps, loads as json_loads
 from logging import getLogger
 
+from enum import Enum
+
+from . import NULL
 from ._vendor.boltons.timeutils import isoparse
 from .collection import AttrDict, frozendict, make_immutable
-from .compat import (integer_types, iteritems, itervalues, odict, string_types, text_type,
-                     with_metaclass, isiterable)
+from .compat import (integer_types, isiterable, iteritems, itervalues, odict, string_types,
+                     text_type, with_metaclass)
 from .exceptions import Raise, ValidationError
-from .ish import find_or_none
+from .ish import find_or_raise
 from .logz import DumpEncoder
 from .type_coercion import maybecall
 
@@ -368,16 +369,20 @@ class Field(object):
     #   on __prepare__.  Strategy lifted from http://stackoverflow.com/a/4460034/2127762
     _order_helper = 0
 
-    def __init__(self, default=None, required=True, validation=None,
-                 in_dump=True, nullable=False, immutable=False):
+    def __init__(self, default=NULL, required=True, validation=None,
+                 in_dump=True, default_in_dump=True, nullable=False, immutable=False, aliases=()):
         self._required = required
         self._validation = validation
         self._in_dump = in_dump
+        self._default_in_dump = default_in_dump
         self._nullable = nullable
         self._immutable = immutable
-        self._default = default if callable(default) else self.box(None, default)
-        if default is not None:
-            self.validate(None, self.box(None, maybecall(default)))
+        self._aliases = aliases
+        if default is NULL:
+            self._default = NULL
+        else:
+            self._default = default if callable(default) else self.box(None, None, default)
+            self.validate(None, self.box(None, None, maybecall(default)))
 
         self._order_helper = Field._order_helper
         Field._order_helper += 1
@@ -405,12 +410,10 @@ class Field(object):
             log.error("The name attribute has not been set for this field.")
             raise AttributeError("The name attribute has not been set for this field.")
         except KeyError:
-            if self.default is not None:
-                val = maybecall(self.default)  # default *can* be a callable
-            elif self._nullable:
-                return None
-            else:
+            if self.default is NULL:
                 raise AttributeError("A value for {0} has not been set".format(self.name))
+            else:
+                val = maybecall(self.default)  # default *can* be a callable
         if val is None and not self.nullable:
             # means the "tricky edge case" was activated in __delete__
             raise AttributeError("The {0} field has been deleted.".format(self.name))
@@ -421,7 +424,7 @@ class Field(object):
             raise AttributeError("The {0} field is immutable.".format(self.name))
         # validate will raise an exception if invalid
         # validate will return False if the value should be removed
-        instance.__dict__[self.name] = self.validate(instance, self.box(instance, val))
+        instance.__dict__[self.name] = self.validate(instance, self.box(instance, instance.__class__, val))
 
     def __delete__(self, instance):
         if self.immutable and instance._initd:
@@ -438,13 +441,13 @@ class Field(object):
         else:
             instance.__dict__.pop(self.name, None)
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         return val
 
     def unbox(self, instance, instance_type, val):
         return val
 
-    def dump(self, val):
+    def dump(self, instance, instance_type, val):
         return val
 
     def validate(self, instance, val):
@@ -459,6 +462,8 @@ class Field(object):
         # note here calling, but not assigning; could lead to unexpected behavior
         if isinstance(val, self._type) and (self._validation is None or self._validation(val)):
             return val
+        elif val is NULL and not self.required:
+            return val
         elif val is None and self.nullable:
             return val
         else:
@@ -480,6 +485,10 @@ class Field(object):
     def in_dump(self):
         return self._in_dump
 
+    @property
+    def default_in_dump(self):
+        return self._default_in_dump
+
     @property
     def nullable(self):
         return self.is_nullable
@@ -496,7 +505,7 @@ class Field(object):
 class BooleanField(Field):
     _type = bool
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         return None if val is None else bool(val)
 
 BoolField = BooleanField
@@ -515,34 +524,34 @@ class NumberField(Field):
 class StringField(Field):
     _type = string_types
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         return text_type(val) if isinstance(val, NumberField._type) else val
 
 
 class DateField(Field):
     _type = datetime
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         try:
             return isoparse(val) if isinstance(val, string_types) else val
         except ValueError as e:
             raise ValidationError(val, msg=e)
 
-    def dump(self, val):
+    def dump(self, instance, instance_type, val):
         return None if val is None else val.isoformat()
 
 
 class EnumField(Field):
 
-    def __init__(self, enum_class, default=None, required=True, validation=None,
-                 in_dump=True, nullable=False, immutable=False):
+    def __init__(self, enum_class, default=NULL, required=True, validation=None,
+                 in_dump=True, default_in_dump=True, nullable=False, immutable=False, aliases=()):
         if not issubclass(enum_class, Enum):
             raise ValidationError(None, msg="enum_class must be an instance of Enum")
         self._type = enum_class
         super(EnumField, self).__init__(default, required, validation,
-                                        in_dump, nullable, immutable)
+                                        in_dump, default_in_dump, nullable, immutable, aliases)
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         if val is None:
             # let the required/nullable logic handle validation for this case
             return None
@@ -556,20 +565,20 @@ class EnumField(Field):
             except KeyError:
                 raise ValidationError(val, msg=e1)
 
-    def dump(self, val):
-        return None if val is None else val.value
+    def dump(self, instance, instance_type, val):
+        return None if val in (None, NULL) else val.value
 
 
 class ListField(Field):
     _type = tuple
 
-    def __init__(self, element_type, default=None, required=True, validation=None,
-                 in_dump=True, nullable=False, immutable=False):
+    def __init__(self, element_type, default=NULL, required=True, validation=None,
+                 in_dump=True, default_in_dump=True, nullable=False, immutable=False, aliases=()):
         self._element_type = element_type
         super(ListField, self).__init__(default, required, validation,
-                                        in_dump, nullable, immutable)
+                                        in_dump, default_in_dump, nullable, immutable, aliases)
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         if val is None:
             return None
         elif isinstance(val, string_types):
@@ -588,23 +597,19 @@ class ListField(Field):
     def unbox(self, instance, instance_type, val):
         return self._type() if val is None and not self.nullable else val
 
-    def dump(self, val):
+    def dump(self, instance, instance_type, val):
         if isinstance(self._element_type, type) and issubclass(self._element_type, Entity):
             return self._type(v.dump() for v in val)
         else:
             return val
 
     def validate(self, instance, val):
-        if val is None:
-            if not self.nullable:
-                raise ValidationError(self.name, val)
-            return None
-        else:
-            val = super(ListField, self).validate(instance, val)
+        val = super(ListField, self).validate(instance, val)
+        if val:
             et = self._element_type
             self._type(Raise(ValidationError(self.name, el, et)) for el in val
                        if not isinstance(el, et))
-            return val
+        return val
 
 
 class MutableListField(ListField):
@@ -614,11 +619,12 @@ class MutableListField(ListField):
 class MapField(Field):
     _type = frozendict
 
-    def __init__(self, default=None, required=True, validation=None,
-                 in_dump=True, nullable=False):
-        super(MapField, self).__init__(default, required, validation, in_dump, nullable, True)
+    def __init__(self, default=NULL, required=True, validation=None,
+                 in_dump=True, default_in_dump=True, nullable=False, immutable=True, aliases=()):
+        super(MapField, self).__init__(default, required, validation, in_dump, default_in_dump,
+                                       nullable, immutable, aliases)
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         # TODO: really need to make this recursive to make any lists or maps immutable
         if val is None:
             return self._type()
@@ -633,16 +639,16 @@ class MapField(Field):
                                            "{0}".format(self.name))
 
 
-
 class ComposableField(Field):
 
-    def __init__(self, field_class, default=None, required=True, validation=None,
-                 in_dump=True, nullable=False, immutable=False):
+    def __init__(self, field_class, default=NULL, required=True, validation=None,
+                 in_dump=True, default_in_dump=True, nullable=False, immutable=False, aliases=()):
         self._type = field_class
         super(ComposableField, self).__init__(default, required, validation,
-                                              in_dump, nullable, immutable)
+                                              in_dump, default_in_dump, nullable, immutable,
+                                              aliases)
 
-    def box(self, instance, val):
+    def box(self, instance, instance_type, val):
         if val is None:
             return None
         if isinstance(val, self._type):
@@ -655,9 +661,16 @@ class ComposableField(Field):
                     val['slf'] = val.pop('self')
             except KeyError:
                 pass  # no key of 'self', so no worries
-            return val if isinstance(val, self._type) else self._type(**val)
+            if isinstance(val, self._type):
+                return val if isinstance(val, self._type) else self._type(**val)
+            elif isinstance(val, Mapping):
+                return self._type(**val)
+            elif isinstance(val, Sequence) and not isinstance(val, string_types):
+                return self._type(*val)
+            else:
+                return self._type(val)
 
-    def dump(self, val):
+    def dump(self, instance, instance_type, val):
         return None if val is None else val.dump()
 
 
@@ -689,11 +702,15 @@ class EntityType(type):
 
     def __init__(cls, name, bases, attr):
         super(EntityType, cls).__init__(name, bases, attr)
-        fields = odict(cls.__fields__) if hasattr(cls, '__fields__') else odict()
-        fields.update(sorted(((name, field.set_name(name))
-                                      for name, field in iteritems(cls.__dict__)
-                                      if isinstance(field, Field)),
-                                     key=lambda item: item[1]._order_helper))
+
+        fields = odict()
+        _field_sort_key = lambda x: x[1]._order_helper
+        for clz in reversed(type.mro(cls)):
+            clz_fields = ((name, field.set_name(name))
+                          for name, field in iteritems(clz.__dict__)
+                          if isinstance(field, Field))
+            fields.update(sorted(clz_fields, key=_field_sort_key))
+
         cls.__fields__ = frozendict(fields)
         if hasattr(cls, '__register__'):
             cls.__register__()
@@ -718,10 +735,13 @@ class Entity(object):
             try:
                 setattr(self, key, kwargs[key])
             except KeyError:
-                # handle the case of fields inherited from subclass but overrode on class object
-                if key in getattr(self, KEY_OVERRIDES_MAP):
+                alias = next((ls for ls in field._aliases if ls in kwargs), None)
+                if alias is not None:
+                    setattr(self, key, kwargs[alias])
+                elif key in getattr(self, KEY_OVERRIDES_MAP):
+                    # handle the case of fields inherited from subclass but overrode on class object
                     setattr(self, key, getattr(self, KEY_OVERRIDES_MAP)[key])
-                elif field.required and field.default is None:
+                elif field.required and field.default is NULL:
                     raise ValidationError(key, msg="{0} requires a {1} field. Instantiated with "
                                                    "{2}".format(self.__class__.__name__,
                                                                 key, kwargs))
@@ -731,13 +751,18 @@ class Entity(object):
         if not self._lazy_validate:
             self.validate()
 
+
     @classmethod
     def from_objects(cls, *objects, **override_fields):
         init_vars = dict()
         search_maps = tuple(AttrDict(o) if isinstance(o, dict) else o
                             for o in ((override_fields,) + objects))
-        for key in cls.__fields__:
-            init_vars[key] = find_or_none(key, search_maps)
+        for key, field in iteritems(cls.__fields__):
+            try:
+                init_vars[key] = find_or_raise(key, search_maps, field._aliases)
+            except AttributeError:
+                pass
+
         return cls(**init_vars)
 
     @classmethod
@@ -765,6 +790,8 @@ class Entity(object):
             # TODO: re-enable once aliases are implemented
             # if key.startswith('_'):
             #     return False
+            if '__' in key:
+                return False
             try:
                 getattr(self, key)
                 return True
@@ -795,10 +822,11 @@ class Entity(object):
         return self.json(indent=indent, separators=separators, **kwargs)
 
     def dump(self):
-        return odict((field.name, field.dump(value))
-                     for field, value in ((field, getattr(self, field.name, None))
+        return odict((field.name, field.dump(self, self.__class__, value))
+                     for field, value in ((field, getattr(self, field.name, NULL))
                                           for field in self.__dump_fields())
-                     if value is not None or field.nullable)
+                     if value is not NULL and not (value is field.default
+                                                   and not field.default_in_dump))
 
     @classmethod
     def __dump_fields(cls):
